Kinto
=====

|coc| |irc| |slack| |readthedocs| |pypi| |travis| |master-coverage|

.. |coc| image:: https://img.shields.io/badge/%E2%9D%A4-code%20of%20conduct-blue.svg
    :target: https://github.com/Kinto/kinto/blob/master/CODE_OF_CONDUCT.md
    :alt: Code of conduct

.. |irc| image:: https://img.shields.io/badge/Live%20chat-%23kinto%20on%20freenode-blue.svg
    :target: https://kiwiirc.com/client/irc.freenode.net/?#kinto

.. |slack| image:: https://img.shields.io/badge/slack-kinto-e01865.svg
    :target: https://slack.kinto-storage.org/

.. |travis| image:: https://travis-ci.org/Kinto/kinto.svg?branch=master
    :target: https://travis-ci.org/Kinto/kinto

.. |readthedocs| image:: https://readthedocs.org/projects/kinto/badge/?version=latest
    :target: https://kinto.readthedocs.io/en/latest/
    :alt: Documentation Status

.. |master-coverage| image::
    https://coveralls.io/repos/Kinto/kinto/badge.svg?branch=master
    :alt: Coverage
    :target: https://coveralls.io/r/Kinto/kinto

.. |pypi| image:: https://img.shields.io/pypi/v/kinto.svg
    :target: https://pypi.python.org/pypi/kinto


Kinto is a minimalist JSON storage service with synchronisation and sharing abilities.

* `Online documentation <https://kinto.readthedocs.io/en/latest/>`_
* `Tutorial <https://kinto.readthedocs.io/en/latest/tutorials/first-steps.html>`_
* `Issue tracker <https://github.com/Kinto/kinto/issues>`_
* `Contributing <https://kinto.readthedocs.io/en/latest/community.html#how-to-contribute>`_
* `Try our daily flushed instance at: https://kinto.dev.mozaws.net/v1/ <https://kinto.dev.mozaws.net/v1/>`_

Requirements
------------

* **Python**: 3.5+
* **Backends**: In-memory (development), Postgresql 9.5+ (production)
